<?php


namespace app\components;

/**
 * Class Validator
 * @package app\components
 */
class Validator
{
    /**
     * Свойство которое хранит в себе массив ошибок
     *
     * @var array
     */
    private array $_errors = [];

    /**
     * Метод валидации
     *
     * @param $src
     * @param array $rules
     */
    public function validate($src, $rules = [], $attribute = [])
    {
        foreach ($src as $item => $item_value) {
            if (key_exists($item, $rules)) {
                foreach ($rules[$item] as $rule => $rule_value) {
                    if (is_int($rule)) {
                        $rule = $rule_value;
                    }

                    // экранируем данные
                    $item_value = escapeFunction($item_value);

                    switch ($rule) {
                        case 'required':
                            if (empty($item_value) && $rule_value) {
                                $this->addError($item,  ucwords($attribute[$item]) . ' обязательно');
                            }
                            break;
                        case 'minLen':
                            if (mb_strlen($item_value) < $rule_value) {
                                $this->addError($item, ucwords($attribute[$item]) . ' должно иметь не менее ' . $rule_value . ' символов');
                            }
                            break;
                        case 'maxLen':
                            if (mb_strlen($item_value) > $rule_value) {
                                $this->addError($item, ucwords($attribute[$item]) . ' должно иметь максимум ' . $rule_value . ' символов');
                            }
                            break;
                        case 'email':
                            if (!filter_var($item_value, FILTER_VALIDATE_EMAIL)) {
                                $this->addError($item, ucwords($attribute[$item]) . ' не является почтовым адресом');
                            }
                    }
                }
            }
        }
    }

    /**
     * Метод добавляет ошибку
     *
     * @param $item
     * @param $error
     */
    private function addError($item, $error)
    {
        $this->_errors[$item][] = 'Поле ' . $error;
    }

    /**
     * Метод возвращает ошибки
     *
     * @return array|false
     */
    public function error()
    {
        if (empty($this->_errors)) {
            return false;
        }

        return $this->_errors;
    }
}