<?php


namespace app\core;

/**
 * Class Router
 * @package app\core
 */
class Router
{
    /**
     * Массив в котором содержится таблица маршрутов
     *
     * @var array
     */
    protected static array $routes = [];

    /**
     * Массив в котором будет содержаться текущий маршрут
     *
     * @var array
     */
    protected static array $route = [];

    /**
     * Метод который добавляет маршруты в таблицу маршруов
     *
     * @param string $regexp
     * @param array $route
     */
    public static function add(string $regexp, $route = [])
    {
        self::$routes[$regexp] = $route;
    }

    /**
     * Метод который возвращает таблицу маршрутов
     */
    public static function getRoutes()
    {
        return self::$routes;
    }

    /**
     * Метод который возвращает текущий маршрут в таблице маршрутов
     */
    public static function getRoute()
    {
        return self::$route;
    }

    /**
     * Метод сверяет текущий адрес с таблицей маршрутов
     *
     * @param $url
     * @return bool
     */
    public static function matchRoute($url)
    {
        foreach (self::$routes as $pattern => $route) {
            if (preg_match("#$pattern#i", $url, $matches)) {
                foreach ($matches as $k => $v) {
                    if (is_string($k)) {
                        $route[$k] = $v;
                    }
                }
                if (!isset($route['action'])) {
                    $route['action'] = 'index';
                }
                $route['controller'] = self::upperCamelCase($route['controller']);
                self::$route = $route;

                return true;
            }
        }

        return false;
    }

    /**
     * Метод который вызывает контроллер и action
     *
     * @param $url
     */
    public static function dispatch($url)
    {
        $url = self::removeQueryString($url);
        if (self::matchRoute($url)) {
            $path = 'app\controllers\\' . self::upperCamelCase(self::$route['controller']) . 'Controller';
            if (class_exists($path)) {
                $action = self::lowerCamelCase(self::$route['action']) . 'Action';
                if (method_exists($path, $action)) {
                    $controller = new $path(self::$route);
                    $controller->$action();
                    $controller->getView();
                } else {
                    echo 'Не найден вид ' . self::lowerCamelCase(self::$route['action']) . 'Action';
                }
            } else {
                echo 'Не найден контроллер ' . self::upperCamelCase(self::$route['controller']) . 'Controller';
            }
        } else {
            echo 'Не найден роут';
        }
    }


    /**
     * Метод преобразовывает имена к виду CamelCase
     *
     * @param string $name
     * @return string
     */
    protected static function upperCamelCase(string $name)
    {
        return str_replace(' ', '', ucwords(str_replace('-', ' ', $name)));
    }

    /**
     * Метод преобразовывает имена к виду CamelCase
     *
     * @param string $name
     * @return string
     */
    protected static function lowerCamelCase(string $name)
    {
        return lcfirst(self::upperCamelCase($name));
    }

    /**
     * Метод который обрезает лишние гет параметры
     *
     * @param $url
     * @return string
     */
    protected static function removeQueryString($url)
    {
        if ($url) {
            $params = explode('&', $url, 2);
            if (false === strpos($params[0], '=')) {
                return rtrim($params[0], '/');
            } else {
                return '';
            }
        }
    }
}