<?php


namespace app\core\base;

use app\components\Session;
use app\models\Admin;

/**
 * Class Controller
 * @package app\core\base
 */
abstract class Controller
{
    /**
     * Текущий маршрут и параметры [controller, action, params]
     *
     * @var array
     */
    public array $route = [];

    /**
     * Текщий вид
     *
     * @var string
     */
    public $view;

    /**
     * Текщий шаблон
     *
     * @var string
     */
    public $layout;

    /**
     * Пользовательские данные
     *
     * @var array
     */
    public array $vars = [];

    /**
     * Свойство в которой хранится контроль доступа к страницам
     * @var
     */
    public $acl;

    /**
     * Конструктор
     *
     * @param $route
     */
    public function __construct($route)
    {
        $this->route = $route;
        $this->view = $route['action'];
    }

    /**
     * Метод заполняет свойство $vars переданные пользователем
     *
     * @param $vars
     */
    public function set($vars)
    {
        $this->vars = $vars;
    }

    /**
     * Метод выводит шаблон и вид
     */
    public function getView()
    {
        $vObj = new View($this->route, $this->layout, $this->view);

        $session = new Session();

        if (!empty($session->get('admin'))) {
            $admin = (new Admin())->getAdmin();

            $this->vars['admin'] = $admin;
        }

        $vObj->render($this->vars);
    }

    /**
     * Загрузка модели
     *
     * @param $name
     * @return mixed
     */
    public function loadModel($name) {
        $path = 'app\models\\'.ucfirst($name);
        if (class_exists($path)) {
            return new $path;
        }
    }

    /**
     * Метод проверки доступа
     *
     * @return bool
     */
    public function checkAcl()
    {
        $this->acl = require INC_ROOT . '/app/acl/' . $this->route['controller'] . '.php';
        $session = new Session();

        if ($this->isAcl('all')) {
            return true;
        } elseif (!empty($session->get('admin')) and $this->isAcl('admin')) {
            return true;
        } elseif (empty($session->get('admin')) and $this->isAcl('guest')) {
            return true;
        }
        return false;
    }

    /**
     * Метод проверяет разрешен ли доступ или нет
     *
     * @param $key
     * @return bool
     */
    public function isAcl($key)
    {
        return in_array($this->route['action'], $this->acl[$key]);
    }
}