<?php


namespace app\core\base;

/**
 * Class View
 * @package app\core\base
 */
class View
{
    /**
     * Текущий маршрут и параметры [controllers, action, params]
     *
     * @var array
     */
    public array $route = [];

    /**
     * Текущий вид
     *
     * @var string
     */
    public string $view;

    /**
     * Текущий шаблон
     *
     * @var string
     */
    public $layout;

    /**
     * Массив в котором содержатся все скрипты выводимые в шаблоне
     *
     * @var array
     */
    public array $scripts = [];

    /**
     * Конструктор
     *
     * @param $route
     * @param string $layout
     * @param string $view
     */
    public function __construct($route, $layout = '', $view = '')
    {
        $this->route = $route;

        if ($layout === false) {
            $this->layout = false;
        } else {
            $this->layout = $layout ?: 'default';
        }

        $this->view = $view;
    }

    /**
     * Метод для обфускации кода
     *
     * @param $buffer
     * @return string|string[]|null
     */
    public function compressed($buffer)
    {
        $buffer = preg_replace(
            array(
                '/\>[^\S ]+/s',
                '/[^\S ]+\</s',
                '/(\s)+/s',
                '/<!--(?![^<]*noindex)(.*?)-->/'
            ),
            array(
                '>',
                '<',
                '\\1',
                ''
            ),
            $buffer
        );

        return $buffer;
    }

    /**
     * Метод который выводит шаблон и вид
     *
     * @param $vars
     */
    public function render($vars)
    {
        if (is_array($vars)) {
            extract($vars);
        }

        $file_view = 'app/views/' . mb_strtolower($this->route['controller']) . '/' . $this->view . '.php';
        $file_layouts = 'app/views/layouts/' . $this->layout . '.php';

        require INC_ROOT . '/app/views/blocks/header.php';

        if (is_file($file_view)) {
            // можно использовать обфускацию кода если нужно, вызвав метод compressed -> ob_start([$this, 'compressed'])
            ob_start();
            require $file_view;
            $content = ob_get_contents();
            ob_clean();
        } else {
            echo '<p>Не найден вид ' . $file_view . '</p>';
        }

        if (false !== $this->layout) {
            if (is_file($file_layouts)) {
                $content = $this->getScripts($content);

                require $file_layouts;
            } else {
                echo '<p>Не найден шаблон ' . $file_layouts . '</p>';
            }
        }

        require INC_ROOT . '/app/views/blocks/footer.php';
    }

    /**
     * Метод переноса всех скриптов вниз
     *
     * @param $content
     * @return string|string[]|null
     */
    protected function getScripts($content)
    {
        $pattern = "#<script.*?>.*?</script>#si";
        preg_match_all($pattern, $content, $this->scripts);
        if (!empty($this->scripts)) {
            $content = preg_replace($pattern, '', $content);
        }

        return $content;
    }
}