<?php


namespace app\models;

use app\components\Security;
use app\components\Session;
use app\core\base\Model;

/**
 * Class Admin
 * @package app\models
 */
class Admin extends Model
{
    /**
     * Правила валидации
     *
     * @return \string[][]
     */
    public function rules()
    {
        return [
            'login' => [
                'required'
            ],
            'password' => [
                'required'
            ]
        ];
    }

    /**
     * Аттрибуты полей
     * @return string[]
     */
    public function attribute()
    {
        return [
            'login' => 'Логин',
            'password' => 'Пароль'
        ];
    }

    /**
     * Метод проверки зарегистрирован ли админ или нет
     *
     * @param $data
     * @return bool
     */
    public function isCheckSign($data)
    {
        $count = $this->db->count('SELECT COUNT(*) as count FROM admin WHERE login = :login', [
            'login' => $data['login']
        ]);

        if ($count > 0) {
            $result = $this->db->fetch('SELECT id, login, password FROM admin WHERE login = :login', [
                'login' => $data['login']
            ]);

            if ((new Security())->validatePasswordHash($data['password'], $result['password'])) {
                (new Session())->set('admin', $result);
                return true;
            }
        }

        return false;
    }

    /**
     * Метод вовзращает данные админа
     *
     * @return array|false|mixed|null
     */
    public function getAdmin()
    {
        $session = new Session();

        if (!empty($session->get('admin'))) {
            return $session->get('admin');
        }

        return false;
    }

    /**
     * Метод который сохраняет измененную задачу
     *
     * @param $data
     * @param $id
     * @return bool|\PDOStatement
     */
    public function editTask($data, $id)
    {
        return $this->db->query('UPDATE tasks SET text = :text, status = :status WHERE id = :id', [
            'text' => $data['text'],
            'status' => $data['taskSuccess'],
            'id' => $id
        ]);
    }
}